intelmq.bots.parsers.threatminer package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.parsers.threatminer package

## Submodules

## intelmq.bots.parsers.threatminer.parser module

intelmq.bots.parsers.threatminer.parser.BOT

  alias of `intelmq.bots.parsers.threatminer.parser.ThreatminerParserBot`

class intelmq.bots.parsers.threatminer.parser.MyHTMLParser(*, convert_charrefs=True)

  Bases: `html.parser.HTMLParser`

  handle_data(data)
  property process_data
  property set_empty_data

class intelmq.bots.parsers.threatminer.parser.ThreatminerParserBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.ParserBot`

  Parse the Threatminer feed

  process()

## Module contents